Learn R Programming

Copula.surv (version 3.0)

U2.Clayton: Estimation of an association parameter via the unweighted estimator

Description

Estimate the association parameter of the Clayton copula using bivariate survival data. The estimator was defined as the unweighted estimator in Emura, Lin and Wang (2010).

Usage

U2.Clayton(x.obs,y.obs,dx,dy,lower=0.001,upper=50,U.plot=TRUE)

Value

theta

association parameter

tau

Kendall's tau (=theta/(theta+2))

Arguments

x.obs

censored times for X

y.obs

censored times for Y

dx

censoring indicators for X

dy

censoring indicators for Y

lower

lower bound for the association parameter

upper

upper bound for the association parameter

U.plot

if TRUE, draw the plot of U_2(theta)

Author

Takeshi Emura

Details

Details are seen from the references.

References

Emura T, Lin CW, Wang W (2010) A goodness-of-fit test for Archimedean copula models in the presence of right censoring, Compt Stat Data Anal 54: 3033-43

Examples

Run this code
n=200
theta_true=2 ## association parameter ##
r1_true=1 ## hazard for X
r2_true=1 ## hazard for Y

set.seed(1)
V1=runif(n)
V2=runif(n)
X=-1/r1_true*log(1-V1)
W=(1-V1)^(-theta_true)
Y=1/theta_true/r2_true*log(  1-W+W*(1-V2)^(-theta_true/(theta_true+1))  )
C=runif(n,min=0,max=5)

x.obs=pmin(X,C)
y.obs=pmin(Y,C)
dx=X<=C
dy=Y<=C

U2.Clayton(x.obs,y.obs,dx,dy)

Run the code above in your browser using DataLab