Learn R Programming

Copula.surv (version 3.0)

U2.Gumbel: Estimation of an association parameter via the pseudo-likelihood

Description

Estimate the association parameter of the Gumbel copula using bivariate survival data. The estimator was derived by Emura, Lin and Wang (2010).

Usage

U2.Gumbel(x.obs,y.obs,dx,dy,lower=0.01,upper=50,U.plot=TRUE)

Value

theta

association parameter

tau

Kendall's tau (=theta/(theta+1))

Arguments

x.obs

censored times for X

y.obs

censored times for Y

dx

censoring indicators for X

dy

censoring indicators for Y

lower

lower bound for the association parameter

upper

upper bound for the association parameter

U.plot

if TRUE, draw the plot of U_2(theta)

Author

Takeshi Emura

Details

Details are seen from the references.

References

Emura T, Lin CW, Wang W (2010) A goodness-of-fit test for Archimedean copula models in the presence of right censoring, Compt Stat Data Anal 54: 3033-43

Examples

Run this code
x.obs=c(1,2,3,4,5)
y.obs=c(2,1,4,5,6)
dx=c(1,1,1,1,1)
dy=c(1,1,1,1,1)
U2.Gumbel(x.obs,y.obs,dx,dy)

Run the code above in your browser using DataLab