powered by
Estimate the association parameter of the Gumbel copula using bivariate survival data. The estimator was derived by Emura, Lin and Wang (2010).
U2.Gumbel(x.obs,y.obs,dx,dy,lower=0.01,upper=50,U.plot=TRUE)
association parameter
Kendall's tau (=theta/(theta+1))
censored times for X
censored times for Y
censoring indicators for X
censoring indicators for Y
lower bound for the association parameter
upper bound for the association parameter
if TRUE, draw the plot of U_2(theta)
Takeshi Emura
Details are seen from the references.
Emura T, Lin CW, Wang W (2010) A goodness-of-fit test for Archimedean copula models in the presence of right censoring, Compt Stat Data Anal 54: 3033-43
x.obs=c(1,2,3,4,5) y.obs=c(2,1,4,5,6) dx=c(1,1,1,1,1) dy=c(1,1,1,1,1) U2.Gumbel(x.obs,y.obs,dx,dy)
Run the code above in your browser using DataLab